@@ -14,41 +14,50 @@
 # limitations under the License.
 #
 
-from google.cloud.iap_v1.services.identity_aware_proxy_admin_service.client import (
-    IdentityAwareProxyAdminServiceClient,
-)
 from google.cloud.iap_v1.services.identity_aware_proxy_admin_service.async_client import (
     IdentityAwareProxyAdminServiceAsyncClient,
 )
-from google.cloud.iap_v1.services.identity_aware_proxy_o_auth_service.client import (
-    IdentityAwareProxyOAuthServiceClient,
+from google.cloud.iap_v1.services.identity_aware_proxy_admin_service.client import (
+    IdentityAwareProxyAdminServiceClient,
 )
 from google.cloud.iap_v1.services.identity_aware_proxy_o_auth_service.async_client import (
     IdentityAwareProxyOAuthServiceAsyncClient,
 )
-
-from google.cloud.iap_v1.types.service import AccessDeniedPageSettings
-from google.cloud.iap_v1.types.service import AccessSettings
-from google.cloud.iap_v1.types.service import ApplicationSettings
-from google.cloud.iap_v1.types.service import Brand
-from google.cloud.iap_v1.types.service import CorsSettings
-from google.cloud.iap_v1.types.service import CreateBrandRequest
-from google.cloud.iap_v1.types.service import CreateIdentityAwareProxyClientRequest
-from google.cloud.iap_v1.types.service import CsmSettings
-from google.cloud.iap_v1.types.service import DeleteIdentityAwareProxyClientRequest
-from google.cloud.iap_v1.types.service import GcipSettings
-from google.cloud.iap_v1.types.service import GetBrandRequest
-from google.cloud.iap_v1.types.service import GetIapSettingsRequest
-from google.cloud.iap_v1.types.service import GetIdentityAwareProxyClientRequest
-from google.cloud.iap_v1.types.service import IapSettings
-from google.cloud.iap_v1.types.service import IdentityAwareProxyClient
-from google.cloud.iap_v1.types.service import ListBrandsRequest
-from google.cloud.iap_v1.types.service import ListBrandsResponse
-from google.cloud.iap_v1.types.service import ListIdentityAwareProxyClientsRequest
-from google.cloud.iap_v1.types.service import ListIdentityAwareProxyClientsResponse
-from google.cloud.iap_v1.types.service import OAuthSettings
-from google.cloud.iap_v1.types.service import ResetIdentityAwareProxyClientSecretRequest
-from google.cloud.iap_v1.types.service import UpdateIapSettingsRequest
+from google.cloud.iap_v1.services.identity_aware_proxy_o_auth_service.client import (
+    IdentityAwareProxyOAuthServiceClient,
+)
+from google.cloud.iap_v1.types.service import (
+    AccessDeniedPageSettings,
+    AccessSettings,
+    ApplicationSettings,
+    Brand,
+    CorsSettings,
+    CreateBrandRequest,
+    CreateIdentityAwareProxyClientRequest,
+    CreateTunnelDestGroupRequest,
+    CsmSettings,
+    DeleteIdentityAwareProxyClientRequest,
+    DeleteTunnelDestGroupRequest,
+    GcipSettings,
+    GetBrandRequest,
+    GetIapSettingsRequest,
+    GetIdentityAwareProxyClientRequest,
+    GetTunnelDestGroupRequest,
+    IapSettings,
+    IdentityAwareProxyClient,
+    ListBrandsRequest,
+    ListBrandsResponse,
+    ListIdentityAwareProxyClientsRequest,
+    ListIdentityAwareProxyClientsResponse,
+    ListTunnelDestGroupsRequest,
+    ListTunnelDestGroupsResponse,
+    OAuthSettings,
+    ReauthSettings,
+    ResetIdentityAwareProxyClientSecretRequest,
+    TunnelDestGroup,
+    UpdateIapSettingsRequest,
+    UpdateTunnelDestGroupRequest,
+)
 
 __all__ = (
     "IdentityAwareProxyAdminServiceClient",
@@ -62,19 +71,27 @@ __all__ = (
     "CorsSettings",
     "CreateBrandRequest",
     "CreateIdentityAwareProxyClientRequest",
+    "CreateTunnelDestGroupRequest",
     "CsmSettings",
     "DeleteIdentityAwareProxyClientRequest",
+    "DeleteTunnelDestGroupRequest",
     "GcipSettings",
     "GetBrandRequest",
     "GetIapSettingsRequest",
     "GetIdentityAwareProxyClientRequest",
+    "GetTunnelDestGroupRequest",
     "IapSettings",
     "IdentityAwareProxyClient",
     "ListBrandsRequest",
     "ListBrandsResponse",
     "ListIdentityAwareProxyClientsRequest",
     "ListIdentityAwareProxyClientsResponse",
+    "ListTunnelDestGroupsRequest",
+    "ListTunnelDestGroupsResponse",
     "OAuthSettings",
+    "ReauthSettings",
     "ResetIdentityAwareProxyClientSecretRequest",
+    "TunnelDestGroup",
     "UpdateIapSettingsRequest",
+    "UpdateTunnelDestGroupRequest",
 )
