@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,12 +33,13 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.iap_v1.services.identity_aware_proxy_o_auth_service import pagers
 from google.cloud.iap_v1.types import service
+
+from .client import IdentityAwareProxyOAuthServiceClient
 from .transports.base import (
-    IdentityAwareProxyOAuthServiceTransport,
     DEFAULT_CLIENT_INFO,
+    IdentityAwareProxyOAuthServiceTransport,
 )
 from .transports.grpc_asyncio import IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport
-from .client import IdentityAwareProxyOAuthServiceClient
 
 
 class IdentityAwareProxyOAuthServiceAsyncClient:
@@ -227,9 +228,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
             from google.cloud import iap_v1
 
-            def sample_list_brands():
+            async def sample_list_brands():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.ListBrandsRequest(
@@ -237,7 +238,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.list_brands(request=request)
+                response = await client.list_brands(request=request)
 
                 # Handle the response
                 print(response)
@@ -273,7 +274,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -289,22 +295,21 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         r"""Constructs a new OAuth brand for the project if one
         does not exist. The created brand is "internal only",
         meaning that OAuth clients created under it only accept
-        requests from users who belong to the same G Suite
-        organization as the project. The brand is created in an
-        un-reviewed status. NOTE: The "internal only" status can
-        be manually changed in the Google Cloud console.
-        Requires that a brand does not already exist for the
-        project, and that the specified support email is owned
-        by the caller.
-
+        requests from users who belong to the same Google
+        Workspace organization as the project. The brand is
+        created in an un-reviewed status. NOTE: The "internal
+        only" status can be manually changed in the Google Cloud
+        Console. Requires that a brand does not already exist
+        for the project, and that the specified support email is
+        owned by the caller.
 
         .. code-block:: python
 
             from google.cloud import iap_v1
 
-            def sample_create_brand():
+            async def sample_create_brand():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.CreateBrandRequest(
@@ -312,7 +317,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_brand(request=request)
+                response = await client.create_brand(request=request)
 
                 # Handle the response
                 print(response)
@@ -351,7 +356,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -370,9 +380,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
             from google.cloud import iap_v1
 
-            def sample_get_brand():
+            async def sample_get_brand():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.GetBrandRequest(
@@ -380,7 +390,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_brand(request=request)
+                response = await client.get_brand(request=request)
 
                 # Handle the response
                 print(response)
@@ -419,7 +429,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -437,14 +452,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         the project exists and that it is set for internal-only
         use.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
 
-            def sample_create_identity_aware_proxy_client():
+            async def sample_create_identity_aware_proxy_client():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.CreateIdentityAwareProxyClientRequest(
@@ -452,7 +466,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_identity_aware_proxy_client(request=request)
+                response = await client.create_identity_aware_proxy_client(request=request)
 
                 # Handle the response
                 print(response)
@@ -491,7 +505,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -510,9 +529,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
             from google.cloud import iap_v1
 
-            def sample_list_identity_aware_proxy_clients():
+            async def sample_list_identity_aware_proxy_clients():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.ListIdentityAwareProxyClientsRequest(
@@ -523,7 +542,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 page_result = client.list_identity_aware_proxy_clients(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -563,12 +582,20 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIdentityAwareProxyClientsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -585,14 +612,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         r"""Retrieves an Identity Aware Proxy (IAP) OAuth client.
         Requires that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
 
-            def sample_get_identity_aware_proxy_client():
+            async def sample_get_identity_aware_proxy_client():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.GetIdentityAwareProxyClientRequest(
@@ -600,7 +626,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_identity_aware_proxy_client(request=request)
+                response = await client.get_identity_aware_proxy_client(request=request)
 
                 # Handle the response
                 print(response)
@@ -639,7 +665,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -656,14 +687,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         secret. Useful if the secret was compromised. Requires
         that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
 
-            def sample_reset_identity_aware_proxy_client_secret():
+            async def sample_reset_identity_aware_proxy_client_secret():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.ResetIdentityAwareProxyClientSecretRequest(
@@ -671,7 +701,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.reset_identity_aware_proxy_client_secret(request=request)
+                response = await client.reset_identity_aware_proxy_client_secret(request=request)
 
                 # Handle the response
                 print(response)
@@ -710,7 +740,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -728,14 +763,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         number of clients in a given project, and cleaning up
         after tests. Requires that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
 
-            def sample_delete_identity_aware_proxy_client():
+            async def sample_delete_identity_aware_proxy_client():
                 # Create a client
-                client = iap_v1.IdentityAwareProxyOAuthServiceClient()
+                client = iap_v1.IdentityAwareProxyOAuthServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iap_v1.DeleteIdentityAwareProxyClientRequest(
@@ -743,7 +777,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_identity_aware_proxy_client(request=request)
+                await client.delete_identity_aware_proxy_client(request=request)
 
         Args:
             request (Union[google.cloud.iap_v1.types.DeleteIdentityAwareProxyClientRequest, dict]):
@@ -774,7 +808,10 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def __aenter__(self):
@@ -786,7 +823,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-iap",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-iap",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
