@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,9 +36,10 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.iap_v1.services.identity_aware_proxy_o_auth_service import pagers
 from google.cloud.iap_v1.types import service
+
 from .transports.base import (
-    IdentityAwareProxyOAuthServiceTransport,
     DEFAULT_CLIENT_INFO,
+    IdentityAwareProxyOAuthServiceTransport,
 )
 from .transports.grpc import IdentityAwareProxyOAuthServiceGrpcTransport
 from .transports.grpc_asyncio import IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport
@@ -61,7 +62,8 @@ class IdentityAwareProxyOAuthServiceClientMeta(type):
     ] = IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[IdentityAwareProxyOAuthServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -172,7 +174,9 @@ class IdentityAwareProxyOAuthServiceClient(
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -185,9 +189,13 @@ class IdentityAwareProxyOAuthServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -196,9 +204,13 @@ class IdentityAwareProxyOAuthServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -207,9 +219,13 @@ class IdentityAwareProxyOAuthServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -218,10 +234,14 @@ class IdentityAwareProxyOAuthServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -393,6 +413,7 @@ class IdentityAwareProxyOAuthServiceClient(
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_brands(
@@ -456,7 +477,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -472,14 +498,13 @@ class IdentityAwareProxyOAuthServiceClient(
         r"""Constructs a new OAuth brand for the project if one
         does not exist. The created brand is "internal only",
         meaning that OAuth clients created under it only accept
-        requests from users who belong to the same G Suite
-        organization as the project. The brand is created in an
-        un-reviewed status. NOTE: The "internal only" status can
-        be manually changed in the Google Cloud console.
-        Requires that a brand does not already exist for the
-        project, and that the specified support email is owned
-        by the caller.
-
+        requests from users who belong to the same Google
+        Workspace organization as the project. The brand is
+        created in an un-reviewed status. NOTE: The "internal
+        only" status can be manually changed in the Google Cloud
+        Console. Requires that a brand does not already exist
+        for the project, and that the specified support email is
+        owned by the caller.
 
         .. code-block:: python
 
@@ -535,7 +560,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -604,7 +634,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -622,7 +657,6 @@ class IdentityAwareProxyOAuthServiceClient(
         the project exists and that it is set for internal-only
         use.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
@@ -679,7 +713,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -754,12 +793,20 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListIdentityAwareProxyClientsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -776,7 +823,6 @@ class IdentityAwareProxyOAuthServiceClient(
         r"""Retrieves an Identity Aware Proxy (IAP) OAuth client.
         Requires that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
@@ -833,7 +879,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -850,7 +901,6 @@ class IdentityAwareProxyOAuthServiceClient(
         secret. Useful if the secret was compromised. Requires
         that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
@@ -907,7 +957,12 @@ class IdentityAwareProxyOAuthServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -925,7 +980,6 @@ class IdentityAwareProxyOAuthServiceClient(
         number of clients in a given project, and cleaning up
         after tests. Requires that the client is owned by IAP.
 
-
         .. code-block:: python
 
             from google.cloud import iap_v1
@@ -974,7 +1028,10 @@ class IdentityAwareProxyOAuthServiceClient(
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def __enter__(self):
@@ -993,7 +1050,9 @@ class IdentityAwareProxyOAuthServiceClient(
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-iap",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-iap",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
