@@ -15,22 +15,24 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
 
 from google.cloud.iap_v1.types import service
-from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-iap",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-iap",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -53,6 +55,7 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -79,10 +82,6 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -104,6 +103,11 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -116,17 +120,28 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_brands: gapic_v1.method.wrap_method(
-                self.list_brands, default_timeout=None, client_info=client_info,
+                self.list_brands,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_brand: gapic_v1.method.wrap_method(
-                self.create_brand, default_timeout=None, client_info=client_info,
+                self.create_brand,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_brand: gapic_v1.method.wrap_method(
-                self.get_brand, default_timeout=None, client_info=client_info,
+                self.get_brand,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_identity_aware_proxy_client: gapic_v1.method.wrap_method(
                 self.create_identity_aware_proxy_client,
@@ -158,9 +173,9 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -246,5 +261,9 @@ class IdentityAwareProxyOAuthServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("IdentityAwareProxyOAuthServiceTransport",)
