@@ -13,20 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.iap_v1.types import service
-from google.protobuf import empty_pb2  # type: ignore
-from .base import IdentityAwareProxyOAuthServiceTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, IdentityAwareProxyOAuthServiceTransport
 
 
 class IdentityAwareProxyOAuthServiceGrpcTransport(
@@ -63,6 +62,7 @@ class IdentityAwareProxyOAuthServiceGrpcTransport(
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -158,6 +158,7 @@ class IdentityAwareProxyOAuthServiceGrpcTransport(
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -229,8 +230,7 @@ class IdentityAwareProxyOAuthServiceGrpcTransport(
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -266,13 +266,13 @@ class IdentityAwareProxyOAuthServiceGrpcTransport(
         Constructs a new OAuth brand for the project if one
         does not exist. The created brand is "internal only",
         meaning that OAuth clients created under it only accept
-        requests from users who belong to the same G Suite
-        organization as the project. The brand is created in an
-        un-reviewed status. NOTE: The "internal only" status can
-        be manually changed in the Google Cloud console.
-        Requires that a brand does not already exist for the
-        project, and that the specified support email is owned
-        by the caller.
+        requests from users who belong to the same Google
+        Workspace organization as the project. The brand is
+        created in an un-reviewed status. NOTE: The "internal
+        only" status can be manually changed in the Google Cloud
+        Console. Requires that a brand does not already exist
+        for the project, and that the specified support email is
+        owned by the caller.
 
         Returns:
             Callable[[~.CreateBrandRequest],
@@ -484,5 +484,9 @@ class IdentityAwareProxyOAuthServiceGrpcTransport(
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("IdentityAwareProxyOAuthServiceGrpcTransport",)
