@@ -13,20 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
+from google.api_core import gapic_v1, grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.iap_v1.types import service
-from google.protobuf import empty_pb2  # type: ignore
-from .base import IdentityAwareProxyOAuthServiceTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, IdentityAwareProxyOAuthServiceTransport
 from .grpc import IdentityAwareProxyOAuthServiceGrpcTransport
 
 
@@ -108,6 +107,7 @@ class IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport(
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -203,6 +203,7 @@ class IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport(
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -270,13 +271,13 @@ class IdentityAwareProxyOAuthServiceGrpcAsyncIOTransport(
         Constructs a new OAuth brand for the project if one
         does not exist. The created brand is "internal only",
         meaning that OAuth clients created under it only accept
-        requests from users who belong to the same G Suite
-        organization as the project. The brand is created in an
-        un-reviewed status. NOTE: The "internal only" status can
-        be manually changed in the Google Cloud console.
-        Requires that a brand does not already exist for the
-        project, and that the specified support email is owned
-        by the caller.
+        requests from users who belong to the same Google
+        Workspace organization as the project. The brand is
+        created in an un-reviewed status. NOTE: The "internal
+        only" status can be manually changed in the Google Cloud
+        Console. Requires that a brand does not already exist
+        for the project, and that the specified support email is
+        owned by the caller.
 
         Returns:
             Callable[[~.CreateBrandRequest],
