@@ -21,21 +21,29 @@ from .service import (
     CorsSettings,
     CreateBrandRequest,
     CreateIdentityAwareProxyClientRequest,
+    CreateTunnelDestGroupRequest,
     CsmSettings,
     DeleteIdentityAwareProxyClientRequest,
+    DeleteTunnelDestGroupRequest,
     GcipSettings,
     GetBrandRequest,
     GetIapSettingsRequest,
     GetIdentityAwareProxyClientRequest,
+    GetTunnelDestGroupRequest,
     IapSettings,
     IdentityAwareProxyClient,
     ListBrandsRequest,
     ListBrandsResponse,
     ListIdentityAwareProxyClientsRequest,
     ListIdentityAwareProxyClientsResponse,
+    ListTunnelDestGroupsRequest,
+    ListTunnelDestGroupsResponse,
     OAuthSettings,
+    ReauthSettings,
     ResetIdentityAwareProxyClientSecretRequest,
+    TunnelDestGroup,
     UpdateIapSettingsRequest,
+    UpdateTunnelDestGroupRequest,
 )
 
 __all__ = (
@@ -46,19 +54,27 @@ __all__ = (
     "CorsSettings",
     "CreateBrandRequest",
     "CreateIdentityAwareProxyClientRequest",
+    "CreateTunnelDestGroupRequest",
     "CsmSettings",
     "DeleteIdentityAwareProxyClientRequest",
+    "DeleteTunnelDestGroupRequest",
     "GcipSettings",
     "GetBrandRequest",
     "GetIapSettingsRequest",
     "GetIdentityAwareProxyClientRequest",
+    "GetTunnelDestGroupRequest",
     "IapSettings",
     "IdentityAwareProxyClient",
     "ListBrandsRequest",
     "ListBrandsResponse",
     "ListIdentityAwareProxyClientsRequest",
     "ListIdentityAwareProxyClientsResponse",
+    "ListTunnelDestGroupsRequest",
+    "ListTunnelDestGroupsResponse",
     "OAuthSettings",
+    "ReauthSettings",
     "ResetIdentityAwareProxyClientSecretRequest",
+    "TunnelDestGroup",
     "UpdateIapSettingsRequest",
+    "UpdateTunnelDestGroupRequest",
 )
